BRValidators class
Class that contains methods for validating Brazilian documents.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
validateCEP(
String cep) → bool - Validates a CEP (Postal Code).
-
validateCNH(
String cnh) → bool - Validates a CNH (National Driver's License).
-
validateCNPJ(
String cnpj) → bool - Validates a CNPJ (National Registry of Legal Entities) number. Supports both numeric and alphanumeric formats (IN RFB 2.229/2024).
-
validateCPF(
String cpf) → bool - Validates a CPF (Brazilian Individual Taxpayer Registry) number.
-
validateIBAN(
String iban) → bool - Validates a Brazilian IBAN number.
-
validateIE(
String ie, String uf) → bool -
Validates an Inscrição Estadual (state tax registration) for the given
uf. -
validateLandlinePhone(
String landlinePhone) → bool - Validates a landline phone number.
-
validateMobileNumber(
String mobileNumber) → bool - Validates a mobile phone number.
-
validateNUP(
String nup) → bool - Validates a NUP (Número Único de Protocolo) government process number.
-
validatePassport(
String passport) → bool - Validates a Brazilian passport number (2 letters + 6 digits).
-
validatePISPASEP(
String pisPasep) → bool - Validates a PIS/PASEP number.
-
validatePixKey(
String key) → bool - Validates a PIX key (CPF, CNPJ, e-mail, phone or random UUID key).
-
validateRENAVAM(
) → bool - Validates a RENAVAM (vehicle registration) number.
-
validateTituloEleitor(
String titulo) → bool - Validates a Título de Eleitor (voter registration card) number.
-
validateUF(
String uf) → bool - Validates a Brazilian state abbreviation (UF).
-
validateVehiclePlate(
String plate) → bool - Validates a Brazilian vehicle license plate (legacy or Mercosul format).