BRMasks class
Class containing mask patterns for Brazilian documents.
Constructors
- BRMasks()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- cep → MaskTextInputFormatter
-
Mask for CEP:
#####-###final - cnh → MaskTextInputFormatter
-
Mask for CNH:
###########final - cnpj → MaskTextInputFormatter
-
Mask for CNPJ (alphanumeric, IN RFB 2.229/2024):
@@.@@@.@@@/@@@@-##final - cpf → MaskTextInputFormatter
-
Mask for CPF:
###.###.###-##final - date → MaskTextInputFormatter
-
Mask for date:
##/##/####final - iban → MaskTextInputFormatter
-
Mask for Brazilian IBAN:
BR## ##### ##### ########## @ #final - ie → MaskTextInputFormatter
-
Mask for Inscrição Estadual (generic 12-digit format):
###.###.###.###final - landlinePhone → MaskTextInputFormatter
-
Mask for landline phone:
(##) ####-####final - mobilePhone → MaskTextInputFormatter
-
Mask for mobile phone:
(##) #####-####final - nup → MaskTextInputFormatter
-
Mask for NUP (Número Único de Protocolo):
#####.######/####-##final - passport → MaskTextInputFormatter
-
Mask for Brazilian passport:
@@######final - pisPasep → MaskTextInputFormatter
-
Mask for PIS/PASEP:
###.#####.##-#final -
Mask for RENAVAM:
###########final - tituloEleitor → MaskTextInputFormatter
-
Mask for Título de Eleitor:
#### #### ####final - vehiclePlateLegacy → MaskTextInputFormatter
-
Mask for legacy vehicle plate:
@@@-####final - vehiclePlateMercosul → MaskTextInputFormatter
-
Mask for Mercosul vehicle plate:
@@@#@##final